@@ -50,7 +50,7 @@ print_mimetypes (void)
 {
 	guint i;
 
-	for (i =0; audio_mime_types[i] != NULL; i++) {
+	for (i =0; i < G_N_ELEMENTS (audio_mime_types); i++) {
 		g_print ("%s\n", audio_mime_types[i]);
 	}
 }
@@ -161,7 +161,9 @@ int main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
+#if !GLIB_CHECK_VERSION (2, 31, 0)
 	g_thread_init (NULL);
+#endif
 
 	g_set_application_name (_("Audio Preview"));
 	g_setenv("PULSE_PROP_application.icon_name", "totem", TRUE);
